@@ -5,5 +5,5 @@ from glQiwiApi.qiwi.clients.wallet.types import WebhookInfo
 
 
 class GetCurrentWebhook(QiwiAPIMethod[WebhookInfo]):
-    url: ClassVar[str] = "https://edge.qiwi.com/payment-notifier/v1/hooks/active"
-    http_method: ClassVar[str] = "GET"
+    url: ClassVar[str] = 'https://edge.qiwi.com/payment-notifier/v1/hooks/active'
+    http_method: ClassVar[str] = 'GET'
