@@ -6,7 +6,7 @@ from glQiwiApi.types.base import Base
 
 
 class NickName(Base):
-    can_change: bool = Field(..., alias="canChange")
-    can_use: bool = Field(..., alias="canUse")
+    can_change: bool = Field(..., alias='canChange')
+    can_use: bool = Field(..., alias='canUse')
     description: str
     nickname: Optional[str] = None
