@@ -1,6 +1,6 @@
 from .adapter import async_as_sync, execute_async_as_sync
 
 __all__ = (
-    "async_as_sync",
-    "execute_async_as_sync",
+    'async_as_sync',
+    'execute_async_as_sync',
 )
